%define Background 	 0x07
%define LineNumber 	 0x05
%define Comment 	 0x0C
%define Data 	 	 0x0E
%define DataQuote 	 0x06
%define DataDelim 	 0x06
%define Special 	 0x02
%define Special2 	 0x0A
%define Numeric 	 0x09
%define InvalidNumber 	 0x4C
%define NumericSuffix 	 0x0D
%define FileNumber 	 0x0D
%define String 	 	 0x0B
%define StringContent 	 0x03
%define Keyword 	 0x0F
%define Identifier 	 0x07
%define Mystery 	 0x30
%define FileNumber	 0x0B

;;;;
;;;;
bits 16
org 100h
;;;;
;;;;

;;;;;;;;;;;;;;;; INSTALLER
_main:
	mov es, [2Ch]
	mov ah, 49h
	int 21h
	
	mov ax, cs
	;mov ds, ax
	les di, [I08ptr]
	shl eax, 16
	mov ax, IRQ0
	cli
	push es
	 push si
	  les si, [es:di] ; Load old I08 pointer
	  cmp [es:si-8], dword 0x4C494853
	  je UninstallInstead
	 pop si
	pop es
	xchg eax, [es:di]
	mov [OldI08], eax
	sti
	
	mov dx,InstalledText ; Display text
	mov ah,9
	int 21h

	mov dx, End          ; Calculate TSR
	sub dx, _main        ; size and do TSR.
	add dx, 15
	shr dx, 4
	add dx, 10h
	mov ax, 3100h
	int 21h
UninstallInstead:
	; Input: ES:SI = Address of IRQ0 routine of the SYNHILI instance to remove
	; Changes: DS, DI
	mov eax, [es:si-4]
	lds di, [cs:I08ptr]
	mov [di], eax ; Restore old IRQ
	sti
	mov ah, 49h ; Free the code segment
	int 21h
	push cs     ; Display text
	pop ds
	mov dx,UninstalledText
	mov ah,9
	int 21h
	mov ax, 4C00h ; Exit
	int 21h

I08ptr: dw 8*4, 0
InstalledText:
	db 'BASIC Syntax highlighting TSR installed',13,10
	db 'Copyright (C) 2010-12-10 Joel Yliluoma, http://iki.fi/bisqwit/',13,10
	db '$'
UninstalledText:
	db 'SYNHILI unloaded.',13,10
	db '$'

StackEnd: ; The installer region is not needed during IRQ, so we can reuse it as the stack.
;;;;;;;;;;;;;;;;;;;;; IRQ

Position:  dw 0, 0xB800
Threshold: dw 0
SavedSPSS  dw 0,0

Signature: dd 0x4C494853
OldI08:    dw 0, 0
IRQ0:
	pusha
	push ds
	mov [cs:SavedSPSS+0], sp
	mov [cs:SavedSPSS+2], ss
	 mov ax,cs
	 mov sp,StackEnd
	 mov ss,ax
	 call Highlight
	lss sp, [cs:SavedSPSS]
	pop ds
	popa
	jmp far [cs:OldI08]

Highlight:
	xor ax,ax
	mov ds,ax
	mov ax, [ds:44Ah]
	cmp ax, 80
	jne Not80ColumnMode
	lds si, [cs:Position]
	cmp [3840], byte 31h
	jne Not80ColumnMode ; Do highlighting only when KEY line is visible.
	cld
	mov cx, [cs:Threshold]
	lea ax, [si+80*2*5]	; process about 5 rows at once
	cmp ax, 24*80*2-2
	jbe htmp
	mov ax, 24*80*2-2
htmp:
	mov [cs:Threshold], ax
	or cx, cx
	je st_newline
	jmp st_idle_entry

ThresholdExceeded:
	jmp EndHighlight

EndHighlight:
	cmp si, 24*80*2
	jb NotResetPosition
	xor si,si
NotResetPosition:
	mov [cs:Position], si
	ret
Not80ColumnMode:
	mov [cs:Position], ds
	mov [cs:Threshold], ds
	ret
;;;;;;;;;;;;;;;;;;;;; UTILITY

;;;;
test_string:
	pop bp        ; at [bp], is labels address
	push bp       ; ss conveniently points to cs, so we use bp here.
test_string_loop:
	lodsw
	cmp al, [bp+2]       ; 2 = string starting offset
	jne test_string_fail
	inc bp
	cmp si, bx
	jb test_string_loop
test_string_match:
        pop bp
        mov bp, [bp]
	jmp word [bp+2]
test_string_fail:
	pop bp
        mov bp, [bp]
	jmp word [bp+0]

;;;;
test_string_uc:
	pop bp        ; at [bp], is labels address
	push bp       ; ss conveniently points to cs, so we use bp here.
test_string_loop_uc:
	call takefrombuffer_uc
	cmp al, [bp+2]       ; 2 = string starting offset
	jne test_string_fail
	inc bp
	cmp si, bx
	jb test_string_loop_uc
	jmp test_string_match

;;;;
takefrombuffer_uc:
	lodsw
makeucase:
	cmp al, 'a'
	jb notlc
	cmp al, 'z'
	ja notlc
	sub al, 32
notlc:	ret

;;;;
binarysearch:
	; don't use: si = source pointer
	;            bx = end pointer
	;            cx = string length
	;            al = input
	; can use:   bp
	;            di
	;            dx
	;            ah
	pop bp ; ss conveniently points to cs, so we use bp here.
	movzx dx, byte[bp]  ; dl=upper limit (exclusive), dh=lower limit
	; Note: yes, they are vice versa. This is intentional.
	; This way, we get hi=count, lo=0 with one instruction.
	jmp binarysearch_loop_assume_nonempty
binarysearch_larger:
	inc ah
	mov dh, ah
	;; jmp binarysearch_loop ;Redundant jump
binarysearch_loop:
	cmp dh, dl
	jae binarysearch_fail
binarysearch_loop_assume_nonempty:
	mov ah, dh
	add ah, dl
	shr ah, 1
	movzx di, ah
	cmp al, [bp+di+3]
	jnbe binarysearch_larger
binarysearch_smaller:
	mov dl, ah
	jne binarysearch_loop
	;; jmp binarysearch_match ;Redundant jump
binarysearch_match:
	movzx dx, byte[bp]
	add di, di ; byte-to-word size
	add bp, dx ; skip over the character options
	jmp word [bp+di+3]  ; bp + ah*2 + dl + 3
binarysearch_fail:
	jmp word [bp+1]


;;;;
paint_token:
	lea si,[bx+1]
paint_token_loop:
	sub si, 2
	mov [si], ah
	loop paint_token_loop
	ret
test_newline:
	mov ax, si
	mov cx, 80*2
	xor dx, dx
	div cx
	test dx, dx
	ret

test_space:
	cmp al,32
	je end_test_space
	cmp al,255
	je end_test_space
	or al,al
end_test_space:
	ret

;powers_of_two:
;  dw 0x0001,0x0002,0x0004,0x0008
;  dw 0x0010,0x0020,0x0040,0x0080
;  dw 0x0100,0x0200,0x0400,0x0800
;  dw 0x1000,0x2000,0x4000,0x8000
;powers_of_two8:
;  db 0x01,0x02,0x04,0x08
;  db 0x10,0x20,0x40,0x80

;;;;;;;;;;;;;;;;;;; PARSING

;erased line;	st_newline_recolor1:
;erased line;		mov byte[si-1], Background
;erased line;		; ; jmp st_newline ;Redundant jump
st_newline:
	mov byte[si+1], Background
	lodsw
	call test_space
	je st_newline
	jmp st_label_noeat ;huh?
st_label_noeat:
	mov byte[si-1], LineNumber
	mov ax,[si-2]
	jmp st_label_atenot
st_label:
	mov byte[si+1], LineNumber
	lodsw
; ; jmp st_label_atenot ;Redundant jump
st_label_atenot:
	sub al, '0'
; <st_label> 0-9
; Case:>=0..9
	cmp al, 9
	ja st_idle_noeat
	jmp st_label
st_label_with_sep_recolor1:
	mov byte[si-1], LineNumber
	; ; jmp st_label_with_sep ;Redundant jump
st_label_with_sep:
	mov byte[si+1], LineNumber
	lodsw
	sub al, ','
; <st_label_sep_recolor1> 0-1
; <st_label_with_sep> 4-13
; Case:>=0..1 - right:4..13
	cmp al, 1
	jbe st_label_sep_recolor1
; Case:4..13
	sub al, 4
	cmp al, 9
	ja st_idle_noeat
	jmp st_label_with_sep
st_label_sep_recolor1:
	mov byte[si-1], Special2
	; ; jmp st_label_sep ;Redundant jump
st_label_sep:
	mov byte[si+1], Special2
	lodsw
	sub al, '0'
; <st_label_with_sep_recolor1> 0-9
; Case:>=0..9
	cmp al, 9
	ja st_idle_noeat
	jmp st_label_with_sep_recolor1
st_idle_noeat:
	mov byte[si-1], Mystery
	mov ax,[si-2]
	jmp st_idle_atenot
st_idle:
	cmp si, [cs:Threshold]
	ja ThresholdExceeded
st_idle_entry:
	mov byte[si+1], Mystery
	call test_newline
	je st_newline
	lodsw
; ; jmp st_idle_atenot ;Redundant jump
st_idle_atenot:
	call test_space
	je st_space_recolor1
	sub al, '('
; <st_special_recolor1> 0-1
; <st_special2_recolor1> 2-3
; <st_special_recolor1> 4-4
; <st_special2_recolor1> 5-5
; <st_period_recolor1> 6-6
; <st_special2_recolor1> 7-7
; <st_number_before_e_recolor1> 8-17
; <st_special_recolor1> 18-19
; <st_special2_recolor1> 20-22
; <st_kw_recolor1> 23-23
; <st_ident_recolor1_buffer> 25-50
; <st_special2_recolor1> 52-52
; <st_special2_recolor1> 54-54
; <st_ident_recolor1_buffer> 57-82
; <st_stringbegin_recolor1> 250-250
; <st_hash_recolor1> 251-251
; <st_etsign_recolor1> 254-254
; <st_comment_recolor1> 255-255
; Case:>=0..1 - right:20..22
	cmp al, 1
	jbe st_special_recolor1
; Case:20..22 - left:6 - right:57..82
	cmp al, 20
	jb L4_0
	cmp al, 22
	jbe st_special2_recolor1
; Case:57..82 - left:25..50 - right:251
	cmp al, '9'
	jb L4_1
	cmp al, 'R'
	jbe st_ident_recolor1_buffer
; Case:251 - left:250<= - right:254
	cmp al, 251
	je st_hash_recolor1
	jae L4_2
; Case:250<=
	cmp al, 250
	jne st_idle
	jmp st_stringbegin_recolor1
L4_2:
; Case:254 - right:>=255<=
	cmp al, 254
	je st_etsign_recolor1
; Case:>=255<=
	jmp st_comment_recolor1
L4_1:
; Case:25..50 - left:>=23 - right:52
	cmp al, 25
	jb L4_3
	cmp al, '2'
	jbe st_ident_recolor1_buffer
; Case:52 - right:54
	cmp al, '4'
	je st_special2_recolor1
; Case:54
	cmp al, '6'
	jne st_idle
	jmp st_special2_recolor1
L4_3:
; Case:>=23
	cmp al, 23
	jne st_idle
	jmp st_kw_recolor1
L4_0:
; Case:6 - left:4 - right:8..17
	cmp al, 6
	je st_period_recolor1
	jae L4_4
; Case:4 - left:>=2..3<= - right:>=5<=
	cmp al, 4
	je st_special_recolor1
	jmp st_special2_recolor1
L4_4:
; Case:8..17 - left:>=7<= - right:>=18..19<=
	cmp al, 17
	ja st_special_recolor1
	cmp al, 8
	jb st_special2_recolor1
	jmp st_number_before_e_recolor1
st_space_recolor1:
	mov byte[si-1], Background
	; ; jmp st_space ;Redundant jump
st_space:
	; reduced version, noeat removed
	jmp st_idle
st_special_recolor1:
	mov byte[si-1], Special
	; ; jmp st_special ;Redundant jump
st_special:
	; reduced version, noeat removed
	jmp st_idle
st_special2_recolor1:
	mov byte[si-1], Special2
	; ; jmp st_special2 ;Redundant jump
st_special2:
	; reduced version, noeat removed
	jmp st_idle
st_period_recolor1:
	mov byte[si-1], Special
	; ; jmp st_period ;Redundant jump
st_period:
	mov byte[si+1], Special
	lodsw
	sub al, '0'
; <st_float_recolor2> 0-9
; Case:>=0..9
	cmp al, 9
	ja st_idle_noeat
	jmp st_float_recolor2
st_remark:
	mov byte[si+1], Comment
	call test_newline
	je st_newline
	lodsw
	sub al, ':'
; <st_idle_noeat> 0-0
; Case:>=0
	jne st_remark
	jmp st_idle_noeat
st_comment_noeat:
	mov byte[si-1], Comment
	mov ax,[si-2]
	jmp st_comment_atenot
st_comment_recolor1:
	mov byte[si-1], Comment
	; ; jmp st_comment ;Redundant jump
st_comment:
	mov byte[si+1], Comment
	call test_newline
	je st_newline
	lodsw
; ; jmp st_comment_atenot ;Redundant jump
st_comment_atenot:
	jmp st_comment ;huh?
st_data_noeat:
	mov byte[si-1], Background
	mov ax,[si-2]
	jmp st_data_atenot
st_data:
	mov byte[si+1], Background
	call test_newline
	je st_newline
	lodsw
; ; jmp st_data_atenot ;Redundant jump
st_data_atenot:
	call test_space
	je st_data
	sub al, '"'
; <st_data_quoted_begin_recolor1> 0-0
; <st_data_delim_recolor1> 10-10
; <st_idle_noeat> 24-24
; Case:>=0 - right:10
	je st_data_quoted_begin_recolor1
; Case:10 - right:24
	cmp al, 10
	je st_data_delim_recolor1
; Case:24
	cmp al, 24
	jne st_data_raw_recolor1
	jmp st_idle_noeat
st_data_delim_recolor1:
	mov byte[si-1], DataDelim
	; ; jmp st_data_delim ;Redundant jump
st_data_delim:
	; reduced version, noeat removed
	jmp st_data
st_data_raw_recolor1:
	mov byte[si-1], Data
	; ; jmp st_data_raw ;Redundant jump
st_data_raw:
	; reduced version, noeat removed
	jmp st_data
st_data_quoted_begin_recolor1:
	mov byte[si-1], DataQuote
	; ; jmp st_data_quoted_begin ;Redundant jump
st_data_quoted_begin:
	; reduced version, noeat removed
	jmp st_data_quoted
st_data_quoted_end_recolor1:
	mov byte[si-1], DataQuote
	; ; jmp st_data_quoted_end ;Redundant jump
st_data_quoted_end:
	; reduced version, noeat removed
	jmp st_data
;erased line;	st_data_quoted_noeat:
;erased line;		mov byte[si-1], Data
;erased line;		mov ax,[si-2]
;erased line;		jmp st_data_quoted_atenot
st_data_quoted:
	mov byte[si+1], Data
	call test_newline
	je st_newline
	lodsw
; ; jmp st_data_quoted_atenot ;Redundant jump
st_data_quoted_atenot:
	sub al, '"'
; <st_data_quoted_end_recolor1> 0-0
; Case:>=0
	jne st_data_quoted
	jmp st_data_quoted_end_recolor1
st_hash_recolor1:
	mov byte[si-1], FileNumber
	; ; jmp st_hash ;Redundant jump
st_hash:
	mov byte[si+1], FileNumber
	lodsw
	sub al, '0'
; <st_hash> 0-9
; Case:>=0..9
	cmp al, 9
	ja st_idle_noeat
	jmp st_hash
st_etsign_recolor1:
	mov byte[si-1], Special
	; ; jmp st_etsign ;Redundant jump
st_etsign:
	mov byte[si+1], Special
	lodsw
	sub al, '0'
; <st_hex_recolor3> 0-9
; <st_hex_recolor3> 17-22
; <st_etsign> 24-24
; <st_etsign> 31-31
; <st_hex_recolor3> 49-54
; <st_etsign> 56-56
; <st_etsign> 63-63
; Case:>=0..9 - right:31
	cmp al, 9
	jbe st_hex_recolor3
; Case:31 - left:17..22 - right:56
	cmp al, 31
	je st_etsign
	jae L10_0
; Case:17..22 - right:24
	sub al, 17
	cmp al, 5
	jbe st_hex_recolor3
; Case:7
	cmp al, 7
	jne st_idle_noeat
	jmp st_etsign
L10_0:
; Case:56 - left:49..54 - right:63
	cmp al, '8'
	je st_etsign
	jae L10_1
; Case:49..54
	sub al, '1'
	cmp al, 5
	ja st_idle_noeat
	jmp st_hex_recolor3
L10_1:
; Case:63
	cmp al, '?'
	jne st_idle_noeat
	jmp st_etsign
st_hex_recolor3:
	mov byte[si-5], Numeric
	; ; jmp st_hex_recolor2 ;Redundant jump
st_hex_recolor2:
	mov byte[si-3], Numeric
	; ; jmp st_hex_recolor1 ;Redundant jump
st_hex_recolor1:
	mov byte[si-1], Numeric
	; ; jmp st_hex ;Redundant jump
st_hex:
	mov byte[si+1], Numeric
	lodsw
	sub al, '0'
; <st_hex> 0-9
; <st_hex> 17-22
; <st_hex> 49-54
; Case:>=0..9 - right:17..22
	cmp al, 9
	jbe st_hex
; Case:17..22 - right:49..54
	sub al, 17
	cmp al, 5
	jbe st_hex
; Case:32..37
	sub al, ' '
	cmp al, 5
	ja st_end_int_noeat
	jmp st_hex
st_number_before_e_recolor1:
	mov byte[si-1], Numeric
	; ; jmp st_number_before_e ;Redundant jump
st_number_before_e:
	mov byte[si+1], Numeric
	lodsw
	sub al, '0'
; <st_number_before_e> 0-9
; <st_epart_recolor1> 20-21
; <st_epart_recolor1> 52-53
; <st_float> 254-254
; Case:>=0..9 - right:52..53
	cmp al, 9
	jbe st_number_before_e
; Case:52..53 - left:20..21 - right:254
	cmp al, '4'
	jb L12_0
	cmp al, '5'
	jbe st_epart_recolor1
; Case:254
	cmp al, 254
	jne st_end_int_noeat
	jmp st_float
L12_0:
; Case:20..21
	sub al, 20
	cmp al, 1
	ja st_end_int_noeat
	jmp st_epart_recolor1
st_float_recolor2:
	mov byte[si-3], Numeric
	; ; jmp st_float_recolor1 ;Redundant jump
st_float_recolor1:
	mov byte[si-1], Numeric
	; ; jmp st_float ;Redundant jump
st_float:
	mov byte[si+1], Numeric
	lodsw
	sub al, '0'
; <st_float> 0-9
; <st_epart_recolor1> 20-21
; <st_epart_recolor1> 52-53
; Case:>=0..9 - right:20..21
	cmp al, 9
	jbe st_float
; Case:20..21 - right:52..53
	sub al, 20
	cmp al, 1
	jbe st_epart_recolor1
; Case:32..33
	sub al, ' '
	cmp al, 1
	ja st_end_float_noeat
	; jmp st_epart_recolor1 ;Redundant jump
st_epart_recolor1:
	mov byte[si-1], InvalidNumber
	; ; jmp st_epart ;Redundant jump
st_epart:
	mov byte[si+1], InvalidNumber
	lodsw
	sub al, '0'
; <st_enum_recolor2> 0-9
; <st_epart2> 251-251
; <st_epart2> 253-253
; Case:>=0..9 - right:251
	cmp al, 9
	jbe st_enum_recolor2
; Case:251 - right:253
	cmp al, 251
	je st_epart2
; Case:253
	cmp al, 253
	jne st_idle_noeat
	; jmp st_epart2 ;Redundant jump
st_epart2:
	mov byte[si+1], InvalidNumber
	lodsw
	sub al, '0'
; <st_enum_recolor3> 0-9
; Case:>=0..9
	cmp al, 9
	ja st_idle_noeat
	; jmp st_enum_recolor3 ;Redundant jump
st_enum_recolor3:
	mov byte[si-5], Numeric
	; ; jmp st_enum_recolor2 ;Redundant jump
st_enum_recolor2:
	mov byte[si-3], Numeric
	; ; jmp st_enum_recolor1 ;Redundant jump
st_enum_recolor1:
	mov byte[si-1], Numeric
	; ; jmp st_enum ;Redundant jump
st_enum:
	mov byte[si+1], Numeric
	lodsw
	sub al, '0'
; <st_enum> 0-9
; Case:>=0..9
	cmp al, 9
	ja st_idle_noeat
	jmp st_enum
st_end_float_noeat:
	mov byte[si-1], NumericSuffix
	mov ax,[si-2]
	; jmp st_end_float_atenot ;Redundant jump
;erased line;	st_end_float:
;erased line;		mov byte[si+1], NumericSuffix
;erased line;		lodsw
;erased line;	; ; jmp st_end_float_atenot ;Redundant jump
st_end_float_atenot:
	sub al, '!'
; <st_idle> 0-0
; <st_idle> 2-2
; Case:>=0 - right:2
	je st_idle
; Case:2
	cmp al, 2
	jne st_idle_noeat
	jmp st_idle
st_end_int_noeat:
	mov byte[si-1], NumericSuffix
	mov ax,[si-2]
	; jmp st_end_int_atenot ;Redundant jump
;erased line;	st_end_int:
;erased line;		mov byte[si+1], NumericSuffix
;erased line;		lodsw
;erased line;	; ; jmp st_end_int_atenot ;Redundant jump
st_end_int_atenot:
	sub al, '%'
; <st_idle> 0-1
; <st_idle> 252-252
; <st_idle> 254-254
; Case:>=0..1 - right:252
	cmp al, 1
	jbe st_idle
; Case:252 - right:254
	cmp al, 252
	je st_idle
; Case:254
	cmp al, 254
	jne st_idle_noeat
	jmp st_idle
st_stringbegin_recolor1:
	mov byte[si-1], String
	; ; jmp st_stringbegin ;Redundant jump
st_stringbegin:
	; reduced version, noeat removed
	jmp st_string
st_stringend_recolor1:
	mov byte[si-1], String
	; ; jmp st_stringend ;Redundant jump
st_stringend:
	; reduced version, noeat removed
	jmp st_idle
;erased line;	st_string_noeat:
;erased line;		mov byte[si-1], StringContent
;erased line;		mov ax,[si-2]
;erased line;		jmp st_string_atenot
st_string:
	mov byte[si+1], StringContent
	call test_newline
	je st_newline
	lodsw
; ; jmp st_string_atenot ;Redundant jump
st_string_atenot:
	sub al, '"'
; <st_stringend_recolor1> 0-0
; Case:>=0
	jne st_string
	jmp st_stringend_recolor1
st_ident_recolor1:
	mov byte[si-1], Identifier
	; ; jmp st_ident ;Redundant jump
st_ident:
	mov byte[si+1], Identifier
	lodsw
	sub al, '#'
; <st_ident> 0-3
; <st_ident> 13-22
; <st_ident> 30-55
; <st_ident> 62-87
; <st_ident> 254-254
; Case:>=0..3 - right:30..55
	cmp al, 3
	jbe st_ident
; Case:30..55 - left:13..22 - right:62..87
	cmp al, 30
	jb L20_0
	cmp al, '7'
	jbe st_ident
; Case:62..87 - right:254
	sub al, '>'
	cmp al, 25
	jbe st_ident
; Case:192
	cmp al, 192
	jne st_idle_noeat_strings2
	jmp st_ident
L20_0:
; Case:13..22
	sub al, 13
	cmp al, 9
	ja st_idle_noeat_strings2
	jmp st_ident
;erased line;	st_kw_noeat:
;erased line;		; reduced version
;erased line;		jmp st_idle_noeat
st_kw_recolor1:
	mov byte[si-1], Keyword
	; ; jmp st_kw ;Redundant jump
st_kw:
	; reduced version, noeat removed
	jmp st_idle
;erased line;	st_specialkw_data_noeat:
;erased line;		; reduced version
;erased line;		jmp st_data_noeat
;erased line;	st_specialkw_data:
;erased line;		; reduced version, noeat removed
;erased line;		jmp st_data
;erased line;	st_specialkw_rem_noeat:
;erased line;		; reduced version
;erased line;		jmp st_comment_noeat
;erased line;	st_specialkw_rem:
;erased line;		; reduced version, noeat removed
;erased line;		jmp st_comment
st_label_kw_noeat:
	mov byte[si-1], Keyword
	mov ax,[si-2]
	jmp st_label_kw_atenot
st_label_kw:
	mov byte[si+1], Keyword
	lodsw
; ; jmp st_label_kw_atenot ;Redundant jump
st_label_kw_atenot:
	call test_space
	je st_label_kw
	sub al, '0'
; <st_label_with_sep_recolor1> 0-9
; Case:>=0..9
	cmp al, 9
	ja st_idle_noeat
	jmp st_label_with_sep_recolor1


st_ident_recolor1_buffer:
	lea bx, [si-2]
	jmp st_ident_recolor1
st_idle_noeat_strings2:
	xchg bx,si

	mov al, [si]
	call makeucase
	cmp al, 'F'
	jne not_fn
maybe_fn:
	mov al, [si+2]
	call makeucase
	cmp al, 'N'
	jne not_fn
is_fn:	mov byte[si+1],Keyword
	mov byte[si+3],Keyword
	jmp sfin0
not_fn:

	sub bx, 2
	mov ax, bx
	sub ax, si
	shr ax, 1
	mov cx, ax
	sub al, 2
	cmp al, 7
	ja sfin0
	movzx bp,al
	shl bp,1
	jmp [bp + T22_0]
T22_0:
	dw pfx5_2_, pfx5_3_, pfx5_4_, pfx5_5_, pfx5_6_, pfx5_7_, pfx5_8_
	dw pfx5_9_
pfx5_3_:
	call takefrombuffer_uc
	call binarysearch
	db 19
	dw sfin0
	db 'A', 'C', 'D', 'E', 'F', 'G', 'I', 'K', 'L', 'M', 'N', 'O', 'P', 'R', 'S', 'T', 'U', 'V', 'X'
	dw pfx5_3_A, pfx5_3_C, pfx5_3_D, pfx5_3_E, pfx5_3_F, pfx5_3_G, pfx5_3_I, pfx5_3_K, pfx5_3_L, pfx5_3_M, pfx5_3_N, pfx5_3_O, pfx5_3_P, pfx5_3_R, pfx5_3_S, pfx5_3_T, pfx5_3_U, pfx5_3_V, pfx5_3_X
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_A ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_C ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_D ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_E ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_F ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_G ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_I ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_K ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_L ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_M ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_N ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_O ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_P ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_R ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_S ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_T ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_U ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_V ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_X ; Dummy jump to prevent dead code elimination
pfx5_3_A:
	call takefrombuffer_uc
	call binarysearch
	db 4
	dw sfin0
	db 'B', 'N', 'S', 'T'
	dw pfx5_3_AB, pfx5_3_AN, pfx5_3_AS, pfx5_3_AT
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_AB ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_AN ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_AS ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_AT ; Dummy jump to prevent dead code elimination
pfx5_4_:
	call takefrombuffer_uc
	call binarysearch
	db 19
	dw sfin0
	db 'A', 'B', 'C', 'D', 'E', 'G', 'H', 'K', 'L', 'M', 'N', 'O', 'P', 'R', 'S', 'T', 'U', 'V', 'W'
	dw pfx5_4_A, pfx5_4_B, pfx5_4_C, pfx5_4_D, pfx5_4_E, pfx5_4_G, pfx5_4_H, pfx5_4_K, pfx5_4_L, pfx5_4_M, pfx5_4_N, pfx5_4_O, pfx5_4_P, pfx5_4_R, pfx5_4_S, pfx5_4_T, pfx5_4_U, pfx5_4_V, pfx5_4_W
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_A ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_B ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_C ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_D ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_E ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_G ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_H ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_K ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_L ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_M ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_N ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_O ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_P ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_R ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_S ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_T ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_U ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_V ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_W ; Dummy jump to prevent dead code elimination
pfx5_4_C:
	call takefrombuffer_uc
	call binarysearch
	db 7
	dw sfin0
	db 'A', 'D', 'H', 'I', 'L', 'O', 'S'
	dw pfx5_4_CA, pfx5_4_CD, pfx5_4_CH, pfx5_4_CI, pfx5_4_CL, pfx5_4_CO, pfx5_4_CS
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_CA ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_CD ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_CH ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_CI ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_CL ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_CO ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_CS ; Dummy jump to prevent dead code elimination
pfx5_3_C:
	call takefrombuffer_uc
	call binarysearch
	db 3
	dw sfin0
	db 'L', 'O', 'V'
	dw pfx5_3_CL, pfx5_3_CO, pfx5_3_CV
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_CL ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_CO ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_CV ; Dummy jump to prevent dead code elimination
pfx5_3_CO:
	call takefrombuffer_uc
	sub al, 'M'
; <pfx_kw> 0-0
; <pfx_kw> 6-6
; Case:>=0 - right:6
	je pfx_kw
; Case:6
	cmp al, 6
	jne sfin0
	jmp pfx_kw
pfx5_6_:
	call takefrombuffer_uc
	call binarysearch
	db 14
	dw sfin0
	db 'A', 'B', 'C', 'D', 'E', 'I', 'L', 'O', 'P', 'R', 'S', 'U', 'V', 'W'
	dw pfx5_6_A, pfx5_6_B, pfx5_6_C, pfx5_6_D, pfx5_6_E, pfx5_6_I, pfx5_6_L, pfx5_6_O, pfx5_6_P, pfx5_6_R, pfx5_6_S, pfx5_6_U, pfx5_6_V, pfx5_6_W
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_A ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_B ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_C ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_D ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_E ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_I ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_L ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_O ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_P ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_R ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_S ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_U ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_V ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_W ; Dummy jump to prevent dead code elimination
pfx5_6_C:
	call takefrombuffer_uc
	call binarysearch
	db 3
	dw sfin0
	db 'I', 'O', 'S'
	dw pfx5_6_CI, pfx5_6_CO, pfx5_6_CS
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_CI ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_CO ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_CS ; Dummy jump to prevent dead code elimination
pfx5_3_CV:
	call takefrombuffer_uc
	call binarysearch
	db 4
	dw sfin0
	db 'D', 'I', 'L', 'S'
	dw pfx_kw, pfx_kw, pfx_kw, pfx_kw
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx_kw ; Dummy jump to prevent dead code elimination
pfx5_8_:
	call takefrombuffer_uc
	sub al, 'E'
; <pfx5_8_E> 0-0
; <pfx5_8_F> 1-1
; Case:>=0 - right:>=1
	je pfx5_8_E
; Case:>=1
	cmp al, 1
	jne sfin0
	jmp pfx5_8_F
pfx5_3_E:
	call takefrombuffer_uc
	call binarysearch
	db 5
	dw sfin0
	db 'N', 'O', 'Q', 'R', 'X'
	dw pfx5_3_EN, pfx5_3_EO, pfx5_3_EQ, pfx5_3_ER, pfx5_3_EX
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_EN ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_EO ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_EQ ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_ER ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_EX ; Dummy jump to prevent dead code elimination
pfx5_5_:
	call takefrombuffer_uc
	call binarysearch
	db 16
	dw sfin0
	db 'A', 'B', 'C', 'D', 'E', 'F', 'G', 'I', 'L', 'M', 'P', 'R', 'S', 'T', 'U', 'W'
	dw pfx5_5_A, pfx5_5_B, pfx5_5_C, pfx5_5_D, pfx5_5_E, pfx5_5_F, pfx5_5_G, pfx5_5_I, pfx5_5_L, pfx5_5_M, pfx5_5_P, pfx5_5_R, pfx5_5_S, pfx5_5_T, pfx5_5_U, pfx5_5_W
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_A ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_B ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_C ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_D ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_E ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_F ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_G ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_I ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_L ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_M ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_P ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_R ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_S ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_T ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_U ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_W ; Dummy jump to prevent dead code elimination
pfx5_5_E:
	call takefrombuffer_uc
	sub al, 'R'
; <pfx5_5_ER> 0-0
; Case:>=0
	jne sfin0
	; jmp pfx5_5_ER ;Redundant jump
pfx5_5_ER:
	call takefrombuffer_uc
	call binarysearch
	db 3
	dw sfin0
	db 'A', 'D', 'R'
	dw pfx5_5_ERA, pfx5_5_ERD, pfx5_5_ERR
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_ERA ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_ERD ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_ERR ; Dummy jump to prevent dead code elimination
pfx5_3_ER:
	call takefrombuffer_uc
	sub al, 'L'
; <pfx_kw> 0-0
; <pfx_kw> 6-6
; Case:>=0 - right:6
	je pfx_kw
; Case:6
	cmp al, 6
	jne sfin0
	jmp pfx_kw
pfx5_6_E:
	call takefrombuffer_uc
	sub al, 'L'
; <pfx5_6_EL> 0-0
; <pfx5_6_EX> 12-12
; Case:>=0 - right:12
	je pfx5_6_EL
; Case:12
	cmp al, 12
	jne sfin0
	jmp pfx5_6_EX
pfx5_3_F:
	call takefrombuffer_uc
	call binarysearch
	db 3
	dw sfin0
	db 'I', 'O', 'R'
	dw pfx5_3_FI, pfx5_3_FO, pfx5_3_FR
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_FI ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_FO ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_FR ; Dummy jump to prevent dead code elimination
pfx5_8_F:
	call takefrombuffer_uc
	call binarysearch
	db 3
	dw sfin0
	db 'I', 'R', 'U'
	dw pfx5_8_FI, pfx5_8_FR, pfx5_8_FU
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_8_FI ; Dummy jump to prevent dead code elimination
	; jmp pfx5_8_FR ; Dummy jump to prevent dead code elimination
	; jmp pfx5_8_FU ; Dummy jump to prevent dead code elimination
pfx5_6_I:
	call takefrombuffer_uc
	sub al, 'N'
; <pfx5_6_IN> 0-0
; <pfx5_6_IO> 1-1
; Case:>=0 - right:>=1
	je pfx5_6_IN
; Case:>=1
	cmp al, 1
	jne sfin0
	jmp pfx5_6_IO
pfx5_6_IN:
	call takefrombuffer_uc
	sub al, 'K'
; <pfx5_6_INK> 0-0
; <pfx5_6_INP> 5-5
; Case:>=0 - right:5
	je pfx5_6_INK
; Case:5
	cmp al, 5
	jne sfin0
	jmp pfx5_6_INP
pfx5_3_I:
	call takefrombuffer_uc
	sub al, 'M'
; <pfx5_3_IM> 0-0
; <pfx5_3_IN> 1-1
; Case:>=0 - right:>=1
	je pfx5_3_IM
; Case:>=1
	cmp al, 1
	jne sfin0
	; jmp pfx5_3_IN ;Redundant jump
pfx5_3_IN:
	call takefrombuffer_uc
	sub al, 'P'
; <pfx_kw> 0-0
; <pfx_kw> 4-4
; Case:>=0 - right:4
	je pfx_kw
; Case:4
	cmp al, 4
	jne sfin0
	jmp pfx_kw
pfx5_5_I:
	call takefrombuffer_uc
	sub al, 'N'
; <pfx5_5_IN> 0-0
; <pfx5_5_IO> 1-1
; Case:>=0 - right:>=1
	je pfx5_5_IN
; Case:>=1
	cmp al, 1
	jne sfin0
	jmp pfx5_5_IO
pfx5_5_IN:
	call takefrombuffer_uc
	sub al, 'P'
; <pfx5_5_INP> 0-0
; <pfx5_5_INS> 3-3
; Case:>=0 - right:3
	je pfx5_5_INP
; Case:3
	cmp al, 3
	jne sfin0
	jmp pfx5_5_INS
pfx5_5_L:
	call takefrombuffer_uc
	sub al, 'E'
; <pfx5_5_LE> 0-0
; <pfx5_5_LL> 7-7
; Case:>=0 - right:7
	je pfx5_5_LE
; Case:7
	cmp al, 7
	jne sfin0
	jmp pfx5_5_LL
pfx5_3_L:
	call takefrombuffer_uc
	sub al, 'E'
; <pfx5_3_LE> 0-0
; <pfx5_3_LO> 10-10
; Case:>=0 - right:10
	je pfx5_3_LE
; Case:10
	cmp al, 10
	jne sfin0
	jmp pfx5_3_LO
pfx5_3_LE:
	call takefrombuffer_uc
	sub al, 'N'
; <pfx_kw> 0-0
; <pfx_kw> 6-6
; Case:>=0 - right:6
	je pfx_kw
; Case:6
	cmp al, 6
	jne sfin0
	jmp pfx_kw
pfx5_3_LO:
	call takefrombuffer_uc
	sub al, 'F'
; <pfx_kw> 0-1
; <pfx_kw> 253-253
; Case:>=0..1 - right:253
	cmp al, 1
	jbe pfx_kw
; Case:253
	cmp al, 253
	jne sfin0
	jmp pfx_kw
pfx5_4_L:
	call takefrombuffer_uc
	call binarysearch
	db 4
	dw sfin0
	db 'I', 'O', 'P', 'S'
	dw pfx5_4_LI, pfx5_4_LO, pfx5_4_LP, pfx5_4_LS
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_LI ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_LO ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_LP ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_LS ; Dummy jump to prevent dead code elimination
pfx5_6_L:
	call takefrombuffer_uc
	call binarysearch
	db 5
	dw sfin0
	db 'B', 'C', 'O', 'P', 'T'
	dw pfx5_6_LB, pfx5_6_LC, pfx5_6_LO, pfx5_6_LP, pfx5_6_LT
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_LB ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_LC ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_LO ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_LP ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_LT ; Dummy jump to prevent dead code elimination
pfx5_4_M:
	call takefrombuffer_uc
	sub al, 'I'
; <pfx5_4_MI> 0-0
; <pfx5_4_MK> 2-2
; Case:>=0 - right:2
	je pfx5_4_MI
; Case:2
	cmp al, 2
	jne sfin0
	; jmp pfx5_4_MK ;Redundant jump
pfx5_4_MK:
	call takefrombuffer_uc
	call binarysearch
	db 4
	dw sfin0
	db 'D', 'I', 'L', 'S'
	dw pfx5_4_MKD, pfx5_4_MKI, pfx5_4_MKL, pfx5_4_MKS
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_MKD ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_MKI ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_MKL ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_MKS ; Dummy jump to prevent dead code elimination
pfx5_4_O:
	call takefrombuffer_uc
	sub al, 'C'
; <pfx5_4_OC> 0-0
; <pfx5_4_OP> 13-13
; Case:>=0 - right:13
	je pfx5_4_OC
; Case:13
	cmp al, 13
	jne sfin0
	jmp pfx5_4_OP
pfx5_4_P:
	call takefrombuffer_uc
	call binarysearch
	db 5
	dw sfin0
	db 'E', 'L', 'M', 'O', 'S'
	dw pfx5_4_PE, pfx5_4_PL, pfx5_4_PM, pfx5_4_PO, pfx5_4_PS
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_PE ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_PL ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_PM ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_PO ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_PS ; Dummy jump to prevent dead code elimination
pfx5_5_P:
	call takefrombuffer_uc
	call binarysearch
	db 4
	dw sfin0
	db 'A', 'C', 'O', 'R'
	dw pfx5_5_PA, pfx5_5_PC, pfx5_5_PO, pfx5_5_PR
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_PA ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_PC ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_PO ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_PR ; Dummy jump to prevent dead code elimination
pfx5_3_P:
	call takefrombuffer_uc
	call binarysearch
	db 3
	dw sfin0
	db 'E', 'O', 'U'
	dw pfx5_3_PE, pfx5_3_PO, pfx5_3_PU
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_PE ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_PO ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_PU ; Dummy jump to prevent dead code elimination
pfx5_6_R:
	call takefrombuffer_uc
	call binarysearch
	db 4
	dw sfin0
	db 'A', 'E', 'I', 'T'
	dw pfx5_6_RA, pfx5_6_RE, pfx5_6_RI, pfx5_6_RT
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_RA ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_RE ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_RI ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_RT ; Dummy jump to prevent dead code elimination
pfx5_3_R:
	call takefrombuffer_uc
	call binarysearch
	db 3
	dw sfin0
	db 'E', 'N', 'U'
	dw pfx5_3_RE, pfx5_3_RN, pfx5_3_RU
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_RE ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_RN ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_RU ; Dummy jump to prevent dead code elimination
pfx5_3_S:
	call takefrombuffer_uc
	call binarysearch
	db 6
	dw sfin0
	db 'E', 'G', 'I', 'P', 'Q', 'U'
	dw pfx5_3_SE, pfx5_3_SG, pfx5_3_SI, pfx5_3_SP, pfx5_3_SQ, pfx5_3_SU
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_SE ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_SG ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_SI ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_SP ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_SQ ; Dummy jump to prevent dead code elimination
	; jmp pfx5_3_SU ; Dummy jump to prevent dead code elimination
pfx5_6_S:
	call takefrombuffer_uc
	call binarysearch
	db 7
	dw sfin0
	db 'C', 'E', 'H', 'I', 'P', 'T', 'Y'
	dw pfx5_6_SC, pfx5_6_SE, pfx5_6_SH, pfx5_6_SI, pfx5_6_SP, pfx5_6_ST, pfx5_6_SY
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_SC ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_SE ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_SH ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_SI ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_SP ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_ST ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_SY ; Dummy jump to prevent dead code elimination
pfx5_5_S:
	call takefrombuffer_uc
	call binarysearch
	db 4
	dw sfin0
	db 'H', 'L', 'O', 'T'
	dw pfx5_5_SH, pfx5_5_SL, pfx5_5_SO, pfx5_5_ST
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_SH ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_SL ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_SO ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_ST ; Dummy jump to prevent dead code elimination
pfx5_5_ST:
	call takefrombuffer_uc
	sub al, 'I'
; <pfx5_5_STI> 0-0
; <pfx5_5_STR> 9-9
; Case:>=0 - right:9
	je pfx5_5_STI
; Case:9
	cmp al, 9
	jne sfin0
	jmp pfx5_5_STR
pfx5_4_S:
	call takefrombuffer_uc
	call binarysearch
	db 4
	dw sfin0
	db 'A', 'E', 'T', 'W'
	dw pfx5_4_SA, pfx5_4_SE, pfx5_4_ST, pfx5_4_SW
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_SA ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_SE ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_ST ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_SW ; Dummy jump to prevent dead code elimination
pfx5_4_ST:
	call takefrombuffer_uc
	call binarysearch
	db 3
	dw sfin0
	db 'E', 'O', 'R'
	dw pfx5_4_STE, pfx5_4_STO, pfx5_4_STR
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_STE ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_STO ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_STR ; Dummy jump to prevent dead code elimination
pfx5_3_T:
	call takefrombuffer_uc
	sub al, 'A'
; <pfx5_3_TA> 0-0
; Case:>=0
	jne sfin0
	; jmp pfx5_3_TA ;Redundant jump
pfx5_3_TA:
	call takefrombuffer_uc
	sub al, 'B'
; <pfx_kw> 0-0
; <pfx_kw> 12-12
; Case:>=0 - right:12
	je pfx_kw
; Case:12
	cmp al, 12
	jne sfin0
	jmp pfx_kw
pfx5_5_T:
	call takefrombuffer_uc
	sub al, 'I'
; <pfx5_5_TI> 0-0
; <pfx5_5_TR> 9-9
; Case:>=0 - right:9
	je pfx5_5_TI
; Case:9
	cmp al, 9
	jne sfin0
	jmp pfx5_5_TR
pfx5_5_TI:
	call takefrombuffer_uc
	sub al, 'M'
; <pfx5_5_TIM> 0-0
; Case:>=0
	jne sfin0
	; jmp pfx5_5_TIM ;Redundant jump
pfx5_5_TIM:
	call takefrombuffer_uc
	sub al, 'E'
; <pfx5_5_TIME> 0-0
; Case:>=0
	jne sfin0
	; jmp pfx5_5_TIME ;Redundant jump
pfx5_5_TIME:
	call takefrombuffer_uc
	sub al, '$'
; <pfx_kw> 0-0
; <pfx_kw> 46-46
; Case:>=0 - right:46
	je pfx_kw
; Case:46
	cmp al, '.'
	jne sfin0
	jmp pfx_kw
pfx5_6_V:
	call takefrombuffer_uc
	sub al, 'A'
; <pfx5_6_VA> 0-0
; Case:>=0
	jne sfin0
	; jmp pfx5_6_VA ;Redundant jump
pfx5_6_VA:
	call takefrombuffer_uc
	sub al, 'R'
; <pfx5_6_VAR> 0-0
; Case:>=0
	jne sfin0
	; jmp pfx5_6_VAR ;Redundant jump
pfx5_6_VAR:
	call takefrombuffer_uc
	sub al, 'P'
; <pfx5_6_VARP> 0-0
; <pfx5_6_VARS> 3-3
; Case:>=0 - right:3
	je pfx5_6_VARP
; Case:3
	cmp al, 3
	jne sfin0
	jmp pfx5_6_VARS
pfx5_7_:
	call takefrombuffer_uc
	call binarysearch
	db 6
	dw sfin0
	db 'E', 'I', 'P', 'R', 'S', 'V'
	dw pfx5_7_E, pfx5_7_I, pfx5_7_P, pfx5_7_R, pfx5_7_S, pfx5_7_V
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_7_E ; Dummy jump to prevent dead code elimination
	; jmp pfx5_7_I ; Dummy jump to prevent dead code elimination
	; jmp pfx5_7_P ; Dummy jump to prevent dead code elimination
	; jmp pfx5_7_R ; Dummy jump to prevent dead code elimination
	; jmp pfx5_7_S ; Dummy jump to prevent dead code elimination
	; jmp pfx5_7_V ; Dummy jump to prevent dead code elimination
pfx5_6_U:
	call takefrombuffer_uc
	call binarysearch
	db 3
	dw sfin0
	db 'B', 'C', 'N'
	dw pfx5_6_UB, pfx5_6_UC, pfx5_6_UN
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_UB ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_UC ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_UN ; Dummy jump to prevent dead code elimination
pfx5_4_B:
	call takefrombuffer_uc
	sub al, 'A'
; <pfx5_4_BA> 0-0
; <pfx5_4_BE> 4-4
; Case:>=0 - right:4
	je pfx5_4_BA
; Case:4
	cmp al, 4
	jne sfin0
	jmp pfx5_4_BE
pfx5_5_B:
	call takefrombuffer_uc
	call binarysearch
	db 3
	dw sfin0
	db 'L', 'S', 'Y'
	dw pfx5_5_BL, pfx5_5_BS, pfx5_5_BY
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_BL ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_BS ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_BY ; Dummy jump to prevent dead code elimination
pfx5_4_CA:
	call takefrombuffer_uc
	sub al, 'L'
; <pfx5_4_CAL> 0-0
; <pfx5_4_CAS> 7-7
; Case:>=0 - right:7
	je pfx5_4_CAL
; Case:7
	cmp al, 7
	jne sfin0
	jmp pfx5_4_CAS
pfx5_5_C:
	call takefrombuffer_uc
	call binarysearch
	db 4
	dw sfin0
	db 'D', 'H', 'L', 'O'
	dw pfx5_5_CD, pfx5_5_CH, pfx5_5_CL, pfx5_5_CO
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_CD ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_CH ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_CL ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_CO ; Dummy jump to prevent dead code elimination
pfx5_5_CH:
	call takefrombuffer_uc
	sub al, 'A'
; <pfx5_5_CHA> 0-0
; <pfx5_5_CHD> 3-3
; Case:>=0 - right:3
	je pfx5_5_CHA
; Case:3
	cmp al, 3
	jne sfin0
	jmp pfx5_5_CHD
pfx5_5_CL:
	call takefrombuffer_uc
	sub al, 'E'
; <pfx5_5_CLE> 0-0
; <pfx5_5_CLO> 10-10
; Case:>=0 - right:10
	je pfx5_5_CLE
; Case:10
	cmp al, 10
	jne sfin0
	jmp pfx5_5_CLO
pfx5_5_CO:
	call takefrombuffer_uc
	sub al, 'L'
; <pfx5_5_COL> 0-0
; <pfx5_5_CON> 2-2
; Case:>=0 - right:2
	je pfx5_5_COL
; Case:2
	cmp al, 2
	jne sfin0
	jmp pfx5_5_CON
pfx5_4_D:
	call takefrombuffer_uc
	sub al, 'A'
; <pfx5_4_DA> 0-0
; <pfx5_4_DR> 17-17
; Case:>=0 - right:17
	je pfx5_4_DA
; Case:17
	cmp al, 17
	jne sfin0
	jmp pfx5_4_DR
pfx5_3_D:
	call takefrombuffer_uc
	sub al, 'E'
; <pfx5_3_DE> 0-0
; <pfx5_3_DI> 4-4
; Case:>=0 - right:4
	je pfx5_3_DE
; Case:4
	cmp al, 4
	jne sfin0
	jmp pfx5_3_DI
pfx5_6_D:
	call takefrombuffer_uc
	sub al, 'E'
; <pfx5_6_DE> 0-0
; <pfx5_6_DO> 10-10
; Case:>=0 - right:10
	je pfx5_6_DE
; Case:10
	cmp al, 10
	jne sfin0
	jmp pfx5_6_DO
pfx5_6_DE:
	call takefrombuffer_uc
	sub al, 'F'
; <pfx5_6_DEF> 0-0
; <pfx5_6_DEL> 6-6
; Case:>=0 - right:6
	je pfx5_6_DEF
; Case:6
	cmp al, 6
	jne sfin0
	jmp pfx5_6_DEL
pfx5_6_DEF:
	call takefrombuffer_uc
	call binarysearch
	db 4
	dw sfin0
	db 'D', 'I', 'L', 'S'
	dw pfx5_6_DEFD, pfx5_6_DEFI, pfx5_6_DEFL, pfx5_6_DEFS
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_DEFD ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_DEFI ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_DEFL ; Dummy jump to prevent dead code elimination
	; jmp pfx5_6_DEFS ; Dummy jump to prevent dead code elimination
pfx5_6_DEFS:
	call takefrombuffer_uc
	sub al, 'G'
; <pfx5_6_DEFSG> 0-0
; <pfx5_6_DEFST> 13-13
; Case:>=0 - right:13
	je pfx5_6_DEFSG
; Case:13
	cmp al, 13
	jne sfin0
	jmp pfx5_6_DEFST
pfx5_4_E:
	call takefrombuffer_uc
	sub al, 'D'
; <pfx5_4_ED> 0-0
; <pfx5_4_EL> 8-8
; Case:>=0 - right:8
	je pfx5_4_ED
; Case:8
	cmp al, 8
	jne sfin0
	jmp pfx5_4_EL
pfx5_5_F:
	call takefrombuffer_uc
	sub al, 'I'
; <pfx5_5_FI> 0-0
; Case:>=0
	jne sfin0
	; jmp pfx5_5_FI ;Redundant jump
pfx5_5_FI:
	call takefrombuffer_uc
	sub al, 'E'
; <pfx5_5_FIE> 0-0
; <pfx5_5_FIL> 7-7
; Case:>=0 - right:7
	je pfx5_5_FIE
; Case:7
	cmp al, 7
	jne sfin0
	jmp pfx5_5_FIL
pfx5_2_:
	call takefrombuffer_uc
	call binarysearch
	db 5
	dw sfin0
	db 'A', 'D', 'I', 'O', 'T'
	dw pfx5_2_A, pfx5_2_D, pfx5_2_I, pfx5_2_O, pfx5_2_T
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_2_A ; Dummy jump to prevent dead code elimination
	; jmp pfx5_2_D ; Dummy jump to prevent dead code elimination
	; jmp pfx5_2_I ; Dummy jump to prevent dead code elimination
	; jmp pfx5_2_O ; Dummy jump to prevent dead code elimination
	; jmp pfx5_2_T ; Dummy jump to prevent dead code elimination
pfx5_2_I:
	call takefrombuffer_uc
	sub al, 'F'
; <pfx_kw> 0-0
; <pfx_kw> 13-13
; Case:>=0 - right:13
	je pfx_kw
; Case:13
	cmp al, 13
	jne sfin0
	jmp pfx_kw
pfx5_4_LI:
	call takefrombuffer_uc
	sub al, 'N'
; <pfx5_4_LIN> 0-0
; <pfx5_4_LIS> 5-5
; Case:>=0 - right:5
	je pfx5_4_LIN
; Case:5
	cmp al, 5
	jne sfin0
	jmp pfx5_4_LIS
pfx5_4_LO:
	call takefrombuffer_uc
	call binarysearch
	db 4
	dw sfin0
	db 'A', 'C', 'N', 'O'
	dw pfx5_4_LOA, pfx5_4_LOC, pfx5_4_LON, pfx5_4_LOO
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_LOA ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_LOC ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_LON ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_LOO ; Dummy jump to prevent dead code elimination
pfx5_5_M:
	call takefrombuffer_uc
	sub al, 'E'
; <pfx5_5_ME> 0-0
; <pfx5_5_MK> 6-6
; Case:>=0 - right:6
	je pfx5_5_ME
; Case:6
	cmp al, 6
	jne sfin0
	jmp pfx5_5_MK
pfx5_4_N:
	call takefrombuffer_uc
	sub al, 'A'
; <pfx5_4_NA> 0-0
; <pfx5_4_NE> 4-4
; Case:>=0 - right:4
	je pfx5_4_NA
; Case:4
	cmp al, 4
	jne sfin0
	jmp pfx5_4_NE
pfx5_3_N:
	call takefrombuffer_uc
	sub al, 'E'
; <pfx5_3_NE> 0-0
; <pfx5_3_NO> 10-10
; Case:>=0 - right:10
	je pfx5_3_NE
; Case:10
	cmp al, 10
	jne sfin0
	jmp pfx5_3_NO
pfx5_6_O:
	call takefrombuffer_uc
	sub al, 'P'
; <pfx5_6_OP> 0-0
; <pfx5_6_OU> 5-5
; Case:>=0 - right:5
	je pfx5_6_OP
; Case:5
	cmp al, 5
	jne sfin0
	jmp pfx5_6_OU
pfx5_3_O:
	call takefrombuffer_uc
	sub al, 'F'
; <pfx5_3_OF> 0-0
; <pfx5_3_OU> 15-15
; Case:>=0 - right:15
	je pfx5_3_OF
; Case:15
	cmp al, 15
	jne sfin0
	jmp pfx5_3_OU
pfx5_4_R:
	call takefrombuffer_uc
	sub al, 'E'
; <pfx5_4_RE> 0-0
; <pfx5_4_RS> 14-14
; Case:>=0 - right:14
	je pfx5_4_RE
; Case:14
	cmp al, 14
	jne sfin0
	jmp pfx5_4_RS
pfx5_5_R:
	call takefrombuffer_uc
	sub al, 'E'
; <pfx5_5_RE> 0-0
; <pfx5_5_RM> 8-8
; Case:>=0 - right:8
	je pfx5_5_RE
; Case:8
	cmp al, 8
	jne sfin0
	jmp pfx5_5_RM
pfx5_5_RE:
	call takefrombuffer_uc
	call binarysearch
	db 3
	dw sfin0
	db 'D', 'N', 'S'
	dw pfx5_5_RED, pfx5_5_REN, pfx5_5_RES
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_RED ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_REN ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_RES ; Dummy jump to prevent dead code elimination
pfx5_6_RE:
	call takefrombuffer_uc
	sub al, 'S'
; <pfx5_6_RES> 0-0
; <pfx5_6_RET> 1-1
; Case:>=0 - right:>=1
	je pfx5_6_RES
; Case:>=1
	cmp al, 1
	jne sfin0
	jmp pfx5_6_RET
pfx5_4_T:
	call takefrombuffer_uc
	call binarysearch
	db 3
	dw sfin0
	db 'H', 'R', 'Y'
	dw pfx5_4_TH, pfx5_4_TR, pfx5_4_TY
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_TH ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_TR ; Dummy jump to prevent dead code elimination
	; jmp pfx5_4_TY ; Dummy jump to prevent dead code elimination
pfx5_4_W:
	call takefrombuffer_uc
	sub al, 'A'
; <pfx5_4_WA> 0-0
; <pfx5_4_WE> 4-4
; Case:>=0 - right:4
	je pfx5_4_WA
; Case:4
	cmp al, 4
	jne sfin0
	jmp pfx5_4_WE
pfx5_5_W:
	call takefrombuffer_uc
	call binarysearch
	db 3
	dw sfin0
	db 'H', 'I', 'R'
	dw pfx5_5_WH, pfx5_5_WI, pfx5_5_WR
	; jmp sfin0 ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_WH ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_WI ; Dummy jump to prevent dead code elimination
	; jmp pfx5_5_WR ; Dummy jump to prevent dead code elimination
pfx5_3_AN:
	call takefrombuffer_uc
	sub al, 'D'
; <pfx_kw> 0-0
; <pfx_kw> 21-21
; Case:>=0 - right:21
	je pfx_kw
; Case:21
	cmp al, 21
	jne sfin0
	jmp pfx_kw
pfx5_6_A:
	call takefrombuffer_uc
	sub al, 'C'
; <pfx5_6_AC> 0-0
; <pfx5_6_AP> 13-13
; Case:>=0 - right:13
	je pfx5_6_AC
; Case:13
	cmp al, 13
	jne sfin0
	jmp pfx5_6_AP
pfx5_2_O:
	call takefrombuffer_uc
	sub al, 'N'
; <pfx_kw> 0-0
; <pfx_kw> 4-4
; Case:>=0 - right:4
	je pfx_kw
; Case:4
	cmp al, 4
	jne sfin0
	jmp pfx_kw
pfx5_6_ST:
	call takefrombuffer_uc
	sub al, 'A'
; <pfx5_6_STA> 0-0
; <pfx5_6_STR> 17-17
; Case:>=0 - right:17
	je pfx5_6_STA
; Case:17
	cmp al, 17
	jne sfin0
	jmp pfx5_6_STR
pfx5_4_U:
	call takefrombuffer_uc
	sub al, 'S'
; <pfx5_4_US> 0-0
; Case:>=0
	jne sfin0
	; jmp pfx5_4_US ;Redundant jump
pfx5_4_US:
	call takefrombuffer_uc
	sub al, 'R'
; <pfx5_4_USR> 0-0
; Case:>=0
	jne sfin0
	; jmp pfx5_4_USR ;Redundant jump
pfx5_4_USR:
	call takefrombuffer_uc
	sub al, '0'
; <pfx_kw> 0-9
; Case:>=0..9
	cmp al, 9
	ja sfin0
	jmp pfx_kw
pfx5_3_AB:
pfx5_3_PO:
pfx5_3_CL:
pfx5_2_A:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'S'
pfx5_3_AS:
pfx5_3_SP:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'C'
pfx5_3_AT:
pfx5_3_SG:
pfx5_3_SI:
pfx5_6_DEFSG:
pfx5_3_PE:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'N'
pfx5_4_CD:
pfx5_6_DEFD:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'BL'
pfx5_4_CH:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'R$'
pfx5_4_CI:
pfx5_4_CO:
pfx5_6_DEFI:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'NT'
pfx5_4_CL:
pfx5_4_CS:
pfx5_6_DEFL:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'NG'
pfx5_6_CS:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'RLIN'
pfx5_8_E:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'NVIRON$'
pfx5_3_EO:
pfx5_3_DE:
pfx5_3_OF:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'F'
pfx5_5_ERD:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'EV'
pfx5_3_EX:
pfx5_4_STO:
pfx5_3_IM:
pfx5_4_LOO:
pfx5_4_STE:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'P'
pfx5_6_EX:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'TERR'
pfx5_3_FI:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'X'
pfx5_3_FR:
pfx5_4_LIN:
pfx5_4_CAS:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'E'
pfx5_8_FR:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'EEFILE'
pfx5_4_H:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'EX$'
pfx5_6_INK:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'EY$'
pfx5_6_INP:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'UT$'
pfx5_5_INS:
pfx5_6_VARP:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'TR'
pfx5_6_IO:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'CTL$'
pfx5_5_LE:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'FT$'
pfx5_4_LP:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'OS'
pfx5_6_LT:
pfx5_6_RT:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'RIM$'
pfx5_4_MI:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'D$'
pfx5_4_MKD:
pfx5_4_MKI:
pfx5_4_MKL:
pfx5_4_MKS:
pfx5_4_STR:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db '$'
pfx5_4_OC:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'T$'
pfx5_4_PE:
pfx5_4_SE:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'EK'
pfx5_4_PM:
pfx5_4_SW:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'AP'
pfx5_5_PO:
pfx5_5_PA:
pfx5_5_PR:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'INT'
pfx5_6_RI:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'GHT$'
pfx5_3_RN:
pfx5_3_EN:
pfx5_4_LOA:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'D'
pfx5_6_SP:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'ACE$'
pfx5_3_SQ:
pfx5_6_DEFST:
pfx5_3_FO:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'R'
pfx5_5_STI:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'CK'
pfx5_3_V:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'AL'
pfx5_7_V:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'ARPTR$'
pfx5_6_VARS:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'EG'
pfx5_6_LB:
pfx5_6_UB:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'OUND'
pfx5_7_S:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'TRING$'
pfx5_6_LC:
pfx5_6_UC:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'ASE$'
pfx5_4_A:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'UTO'
pfx5_4_BE:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'EP'
pfx5_5_BL:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'OAD'
pfx5_5_BS:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'AVE'
pfx5_4_CAL:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'L'
pfx5_5_CHA:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'IN'
pfx5_5_CHD:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'IR'
pfx5_6_CI:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'RCLE'
pfx5_5_CLE:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'AR'
pfx5_5_CLO:
pfx5_5_ERA:
pfx5_4_BA:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'SE'
pfx5_5_COL:
pfx5_5_ERR:
pfx5_3_X:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'OR'
pfx5_6_CO:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'MMON'
pfx5_4_DA:
	call test_string_uc
	dw l_sfin0_pfx_specialkw_data
	db 'TA'
pfx5_5_D:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'ATE$'
pfx5_3_SE:
pfx5_4_LON:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'G'
pfx5_6_DEL:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'ETE'
pfx5_3_DI:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'M'
pfx5_4_DR:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'AW'
pfx5_4_ED:
pfx5_4_WA:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'IT'
pfx5_7_E:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'NVIRON'
pfx5_5_FIE:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'LD'
pfx5_5_FIL:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'ES'
pfx5_3_G:
pfx5_4_LS:
pfx5_4_PS:
pfx5_5_RES:
pfx5_4_RS:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'ET'
pfx5_5_G:
	call test_string_uc
	dw l_sfin0_pfx_label_kw
	db 'OSUB'
pfx5_4_G:
	call test_string_uc
	dw l_sfin0_pfx_label_kw
	db 'OTO'
pfx5_5_INP:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'UT'
pfx5_5_IO:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'CTL'
pfx5_3_K:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'EY'
pfx5_4_K:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'ILL'
pfx5_4_LIS:
	call test_string_uc
	dw l_sfin0_pfx_label_kw
	db 'T'
pfx5_5_LL:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'IST'
pfx5_6_LO:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'CATE'
pfx5_4_LOC:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'K'
pfx5_6_LP:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'RINT'
pfx5_5_ME:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'RGE'
pfx5_5_MK:
pfx5_5_RM:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'DIR'
pfx5_4_NA:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'ME'
pfx5_3_NE:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'W'
pfx5_4_NE:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'XT'
pfx5_4_OP:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'EN'
pfx5_6_OP:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'TION'
pfx5_3_OU:
pfx5_3_PU:
pfx5_3_NO:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'T'
pfx5_7_P:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'ALETTE'
pfx5_5_PC:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'OPY'
pfx5_4_PL:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'AY'
pfx5_4_PO:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'KE'
pfx5_6_P:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'RESET'
pfx5_9_:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'RANDOMIZE'
pfx5_4_RE:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'AD'
pfx5_3_RE:
	call test_string_uc
	dw l_sfin0_pfx_specialkw_rem
	db 'M'
pfx5_5_REN:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'UM'
pfx5_7_R:
	call test_string_uc
	dw l_sfin0_pfx_label_kw
	db 'ESTORE'
pfx5_6_RES:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'UME'
pfx5_6_RET:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'URN'
pfx5_3_RU:
	call test_string_uc
	dw l_sfin0_pfx_label_kw
	db 'N'
pfx5_4_SA:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'VE'
pfx5_6_SC:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'REEN'
pfx5_5_SH:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'ELL'
pfx5_5_SO:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'UND'
pfx5_5_STR:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'IG'
pfx5_6_SY:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'STEM'
pfx5_5_TR:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'OFF'
pfx5_4_TR:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'ON'
pfx5_5_U:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'SING'
pfx5_6_UN:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'LOCK'
pfx5_4_V:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'IEW'
pfx5_4_WE:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'ND'
pfx5_5_WH:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'ILE'
pfx5_5_WI:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'DTH'
pfx5_6_W:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'INDOW'
pfx5_5_WR:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'ITE'
pfx5_5_RED:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'IM'
pfx5_5_SL:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'EEP'
pfx5_6_SE:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'LECT'
pfx5_6_EL:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'SEIF'
pfx5_4_EL:
	call test_string_uc
	dw l_sfin0_pfx_label_kw
	db 'SE'
pfx5_3_M:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'OD'
pfx5_3_EQ:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'V'
pfx5_6_AC:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'CESS'
pfx5_5_A:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'LIAS'
pfx5_6_AP:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'PEND'
pfx5_6_B:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'INARY'
pfx5_5_BY:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'VAL'
pfx5_5_CD:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'ECL'
pfx5_5_CON:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'ST'
pfx5_2_D:
pfx5_2_T:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'O'
pfx5_6_DO:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'UBLE'
pfx5_8_FI:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'LEATTR'
pfx5_8_FU:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'NCTION'
pfx5_7_I:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'NTEGER'
pfx5_6_OU:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'TPUT'
pfx5_6_RA:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'NDOM'
pfx5_6_SH:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'ARED'
pfx5_6_SI:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'NGLE'
pfx5_6_STA:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'TIC'
pfx5_6_STR:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'ING'
pfx5_3_SU:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'B'
pfx5_4_TH:
	call test_string_uc
	dw l_sfin0_pfx_label_kw
	db 'EN'
pfx5_4_TY:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'PE'
pfx5_3_U:
	call test_string_uc
	dw l_sfin0_pfx_kw
	db 'SR'
l_sfin0_pfx_kw:
	dw sfin0, pfx_kw
l_sfin0_pfx_specialkw_data:
	dw sfin0, pfx_specialkw_data
l_sfin0_pfx_label_kw:
	dw sfin0, pfx_label_kw
l_sfin0_pfx_specialkw_rem:
	dw sfin0, pfx_specialkw_rem
; pfx5_ABS:
; pfx5_ASC:
; pfx5_ATN:
; pfx5_CDBL:
; pfx5_CHR_s:
; pfx5_CINT:
; pfx5_CLNG:
; pfx5_COS:
; pfx5_CSNG:
; pfx5_CSRLIN:
; pfx5_CVD:
; pfx5_CVI:
; pfx5_CVL:
; pfx5_CVS:
; pfx5_ENVIRON_s:
; pfx5_EOF:
; pfx5_ERDEV:
; pfx5_ERL:
; pfx5_ERR:
; pfx5_EXP:
; pfx5_EXTERR:
; pfx5_FIX:
; pfx5_FRE:
; pfx5_FREEFILE:
; pfx5_HEX_s:
; pfx5_INKEY_s:
; pfx5_INP:
; pfx5_INPUT_s:
; pfx5_INSTR:
; pfx5_INT:
; pfx5_IOCTL_s:
; pfx5_LEFT_s:
; pfx5_LEN:
; pfx5_LOC:
; pfx5_LOF:
; pfx5_LOG:
; pfx5_LPOS:
; pfx5_LTRIM_s:
; pfx5_MID_s:
; pfx5_MKD_s:
; pfx5_MKI_s:
; pfx5_MKL_s:
; pfx5_MKS_s:
; pfx5_OCT_s:
; pfx5_PEEK:
; pfx5_PMAP:
; pfx5_POINT:
; pfx5_POS:
; pfx5_RIGHT_s:
; pfx5_RND:
; pfx5_RTRIM_s:
; pfx5_SGN:
; pfx5_SIN:
; pfx5_SPACE_s:
; pfx5_SPC:
; pfx5_SQR:
; pfx5_STICK:
; pfx5_STR_s:
; pfx5_TAB:
; pfx5_TAN:
; pfx5_TIMER:
; pfx5_VAL:
; pfx5_VARPTR:
; pfx5_VARPTR_s:
; pfx5_VARSEG:
; pfx5_LBOUND:
; pfx5_UBOUND:
; pfx5_STRING_s:
; pfx5_LCASE_s:
; pfx5_UCASE_s:
; pfx5_AUTO:
; pfx5_BEEP:
; pfx5_BLOAD:
; pfx5_BSAVE:
; pfx5_CALL:
; pfx5_CHAIN:
; pfx5_CHDIR:
; pfx5_CIRCLE:
; pfx5_CLEAR:
; pfx5_CLOSE:
; pfx5_CLS:
; pfx5_COLOR:
; pfx5_COM:
; pfx5_COMMON:
; pfx5_CONT:
; pfx5_DATE_s:
; pfx5_DEF:
; pfx5_DEFDBL:
; pfx5_DEFINT:
; pfx5_DEFLNG:
; pfx5_DEFSGN:
; pfx5_DEFSTR:
; pfx5_SEG:
; pfx5_DELETE:
; pfx5_DIM:
; pfx5_DRAW:
; pfx5_EDIT:
; pfx5_END:
; pfx5_ENVIRON:
; pfx5_ERASE:
; pfx5_ERROR:
; pfx5_FIELD:
; pfx5_FILES:
; pfx5_FOR:
; pfx5_GET:
; pfx5_IF:
; pfx5_INPUT:
; pfx5_IOCTL:
; pfx5_KEY:
; pfx5_KILL:
; pfx5_LET:
; pfx5_LINE:
; pfx5_LLIST:
; pfx5_LOAD:
; pfx5_LOCATE:
; pfx5_LOCK:
; pfx5_LPRINT:
; pfx5_LSET:
; pfx5_MERGE:
; pfx5_MKDIR:
; pfx5_NAME:
; pfx5_NEW:
; pfx5_NEXT:
; pfx5_OPEN:
; pfx5_OPTION:
; pfx5_BASE:
; pfx5_OUT:
; pfx5_PAINT:
; pfx5_PALETTE:
; pfx5_PCOPY:
; pfx5_PEN:
; pfx5_PLAY:
; pfx5_POKE:
; pfx5_PRESET:
; pfx5_PRINT:
; pfx5_PSET:
; pfx5_PUT:
; pfx5_RANDOMIZE:
; pfx5_READ:
; pfx5_RENUM:
; pfx5_RESET:
; pfx5_RESUME:
; pfx5_RETURN:
; pfx5_RMDIR:
; pfx5_RSET:
; pfx5_SAVE:
; pfx5_SCREEN:
; pfx5_SHELL:
; pfx5_SOUND:
; pfx5_STOP:
; pfx5_STRIG:
; pfx5_SWAP:
; pfx5_SYSTEM:
; pfx5_TIME_s:
; pfx5_TROFF:
; pfx5_TRON:
; pfx5_USING:
; pfx5_UNLOCK:
; pfx5_VIEW:
; pfx5_WAIT:
; pfx5_WEND:
; pfx5_WHILE:
; pfx5_WIDTH:
; pfx5_WINDOW:
; pfx5_WRITE:
; pfx5_REDIM:
; pfx5_SEEK:
; pfx5_SLEEP:
; pfx5_SELECT:
; pfx5_CASE:
; pfx5_ELSEIF:
; pfx5_AND:
; pfx5_IMP:
; pfx5_MOD:
; pfx5_NOT:
; pfx5_XOR:
; pfx5_EQV:
; pfx5_ACCESS:
; pfx5_ALIAS:
; pfx5_ANY:
; pfx5_APPEND:
; pfx5_AS:
; pfx5_BINARY:
; pfx5_BYVAL:
; pfx5_CDECL:
; pfx5_CONST:
; pfx5_DO:
; pfx5_DOUBLE:
; pfx5_FILEATTR:
; pfx5_FUNCTION:
; pfx5_INTEGER:
; pfx5_IS:
; pfx5_LONG:
; pfx5_LOOP:
; pfx5_OFF:
; pfx5_ON:
; pfx5_OR:
; pfx5_OUTPUT:
; pfx5_RANDOM:
; pfx5_SHARED:
; pfx5_SINGLE:
; pfx5_STATIC:
; pfx5_STEP:
; pfx5_STRING:
; pfx5_SUB:
; pfx5_TO:
; pfx5_TYPE:
; pfx5_USR:
; pfx5_USR0:
; pfx5_USR1:
; pfx5_USR2:
; pfx5_USR3:
; pfx5_USR4:
; pfx5_USR5:
; pfx5_USR6:
; pfx5_USR7:
; pfx5_USR8:
; pfx5_USR9:
pfx_kw:
	mov ah, Keyword
	call paint_token
sfin0:	lea si,[bx+2]
	jmp st_idle_noeat ; chain jump of st_kw_noeat
; pfx5_GOSUB:
; pfx5_GOTO:
; pfx5_LIST:
; pfx5_RESTORE:
; pfx5_RUN:
; pfx5_ELSE:
; pfx5_THEN:
pfx_label_kw:
	mov ah, Keyword
	call paint_token
	lea si,[bx+2]
	jmp st_label_kw_noeat
; pfx5_DATA:
pfx_specialkw_data:
	mov ah, Keyword
	call paint_token
	lea si,[bx+2]
	jmp st_data_noeat ; chain jump of st_specialkw_data_noeat
; pfx5_REM:
pfx_specialkw_rem:
	mov ah, Keyword
	call paint_token
	lea si,[bx+2]
	jmp st_comment_noeat ; chain jump of st_specialkw_rem_noeat

End:



